Package: radEmu
Title: Using Relative Abundance Data to Estimate of Multiplicative
        Differences in Mean Absolute Abundance
Version: 2.3.2.0
Authors@R: c(person("David", "Clausen", role = c("aut")),
             person("Amy D", "Willis", email = "adwillis@uw.edu", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-2802-4317")),
             person("Sarah", "Teichman", role = "aut"))
Description: A differential abundance method for the analysis of microbiome data. 'radEmu' estimates fold-differences in the abundance of taxa across samples relative to "typical" fold-differences. Notably, it does not require pseudocounts, nor choosing a denominator taxon. For more details, see Clausen et al. (2026) <doi:10.1093/biomet/asag009>. 
URL: https://github.com/statdivlab/radEmu,
        https://statdivlab.github.io/radEmu/
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: MASS, Matrix, methods, magrittr, rlang, R (>= 2.10)
Suggests: testthat (>= 3.0.0), numDeriv, phyloseq,
        TreeSummarizedExperiment, SummarizedExperiment,
        SingleCellExperiment, knitr, dplyr, ggplot2, stringr, parallel,
        rmarkdown
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-02 22:46:33 UTC; sarahteichman
Author: David Clausen [aut],
  Amy D Willis [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-2802-4317>),
  Sarah Teichman [aut]
Maintainer: Amy D Willis <adwillis@uw.edu>
Repository: CRAN
Date/Publication: 2026-04-03 00:20:02 UTC
Built: R 4.4.3; ; 2026-04-07 23:06:33 UTC; unix
