# Generated by roxygen2: do not edit by hand

S3method(plot,emuFit)
S3method(print,emuFit)
export(control_fn)
export(dpseudohuber_median_dx)
export(dpsuedohuber_median_dx)
export(emuFit)
export(emuFit_micro)
export(make_design_matrix)
export(make_reference_constraints)
export(pseudohuber_median)
export(psuedohuber_median)
export(score_test)
import(MASS)
import(Matrix)
importFrom(magrittr,"%>%")
importFrom(methods,as)
importFrom(rlang,.data)
importFrom(stats,cov)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,qnorm)
importFrom(stats,rbinom)
importFrom(stats,reorder)
importFrom(stats,rnbinom)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
